==> love-0.7.2.tar.gz: love-0.7.2/src/modules/image/wrap_ImageData.h <==
/**
* Copyright (c) 2006-2011 LOVE Development Team
* 
* This software is provided 'as-is', without any express or implied
* warranty.  In no event will the authors be held liable for any damages
* arising from the use of this software.
* 
* Permission is granted to anyone to use this software for any purpose,
* including commercial applications, and to alter it and redistribute it
* freely, subject to the following restrictions:
* 
* 1. The origin of this software must not be misrepresented; you must not
*    claim that you wrote the original software. If you use this software
*    in a product, an acknowledgment in the product documentation would be
*    appreciated but is not required.
* 2. Altered source versions must be plainly marked as such, and must not be
*    misrepresented as being the original software.
* 3. This notice may not be removed or altered from any source distribution.
**/

#ifndef LOVE_IMAGE_WRAP_IMAGE_DATA_H
#define LOVE_IMAGE_WRAP_IMAGE_DATA_H

// LOVE
#include <common/runtime.h>
#include "ImageData.h"

namespace love
{
namespace image
{
	ImageData * luax_checkimagedata(lua_State * L, int idx);
	int w_ImageData_getWidth(lua_State * L);
	int w_ImageData_getHeight(lua_State * L);
	int w_ImageData_getPixel(lua_State * L);
	int w_ImageData_setPixel(lua_State * L);
	int w_ImageData_mapPixel(lua_State * L);
	int w_ImageData_getString(lua_State * L);
	int w_ImageData_paste(lua_State * L);
	int w_ImageData_encode(lua_State * L);
	int luaopen_imagedata(lua_State * L);

} // image
} // love

#endif // LOVE_IMAGE_WRAP_IMAGE_DATA_H

==> love-0.8.0.tar.gz: love-0.8.0/src/modules/image/wrap_ImageData.h <==
/**
* Copyright (c) 2006-2012 LOVE Development Team
*
* This software is provided 'as-is', without any express or implied
* warranty.  In no event will the authors be held liable for any damages
* arising from the use of this software.
*
* Permission is granted to anyone to use this software for any purpose,
* including commercial applications, and to alter it and redistribute it
* freely, subject to the following restrictions:
*
* 1. The origin of this software must not be misrepresented; you must not
*    claim that you wrote the original software. If you use this software
*    in a product, an acknowledgment in the product documentation would be
*    appreciated but is not required.
* 2. Altered source versions must be plainly marked as such, and must not be
*    misrepresented as being the original software.
* 3. This notice may not be removed or altered from any source distribution.
**/

#ifndef LOVE_IMAGE_WRAP_IMAGE_DATA_H
#define LOVE_IMAGE_WRAP_IMAGE_DATA_H

// LOVE
#include <common/runtime.h>
#include "ImageData.h"

namespace love
{
namespace image
{
	ImageData * luax_checkimagedata(lua_State * L, int idx);
	int w_ImageData_getWidth(lua_State * L);
	int w_ImageData_getHeight(lua_State * L);
	int w_ImageData_getPixel(lua_State * L);
	int w_ImageData_setPixel(lua_State * L);
	int w_ImageData_mapPixel(lua_State * L);
	int w_ImageData_getString(lua_State * L);
	int w_ImageData_paste(lua_State * L);
	int w_ImageData_encode(lua_State * L);
	extern "C" int luaopen_imagedata(lua_State * L);

} // image
} // love

#endif // LOVE_IMAGE_WRAP_IMAGE_DATA_H
